@@ -1,6 +1,6 @@
 // ------------------------------------------------------------------------
 // ecasound.cpp: Console mode user interface to ecasound.
-// Copyright (C) 2002-2008 Kai Vehmanen
+// Copyright (C) 2002-2009 Kai Vehmanen
 //
 // Attributes:
 //     eca-style-version: 3 (see Ecasound Programmer's Guide)
@@ -55,7 +55,7 @@
  */
 
 static void ecasound_create_eca_objects(struct ecasound_state* state, COMMAND_LINE& cline);
-static void ecasound_launch_daemon(struct ecasound_state* state);
+static void ecasound_launch_neteci(struct ecasound_state* state);
 static int ecasound_pass_at_launch_commands(struct ecasound_state* state);
 static void ecasound_main_loop(struct ecasound_state* state);
 void ecasound_parse_command_line(struct ecasound_state* state, 
@@ -78,13 +78,13 @@ static struct ecasound_state ecasound_state_global =
     0,        /* ECA_NETECI_SERVER */
     0,        /* ECA_SESSION */
     0,        /* launchcmds, std::vector<std::string> */
-    0,        /* pthread_t - daemon_thread */
-    0,        /* pthread_mutex_t - lock */
+    0,        /* pthread_t - NetECI_thread */
+    0,        /* pthread_mutex_t - lock protecting 'control' object */
     0,        /* sig_wait_t - exit_request */
     0,        /* sigset_t */
     ECASOUND_RETVAL_SUCCESS, /* int - return value */
-    2868,     /* int - default daemon mode TCP-port */
-    false,    /* daemon mode */
+    2868,     /* int - default NetECI mode TCP-port */
+    false,    /* NetECI (TCP control) mode */
     false,    /* keep_running mode */
     false,    /* cerr-output-only mode */
     false,    /* interactive mode */
@@ -149,10 +149,10 @@ int main(int argc, char *argv[])
     ecasound_create_eca_objects(state, *clineout);
     delete clineout; clineout = 0;
 
-    /* 7. start ecasound daemon */
+    /* 7. enable control over socket connection  */
     if (state->retval == ECASOUND_RETVAL_SUCCESS) {
-      if (state->daemon_mode == true) {
-	ecasound_launch_daemon(state);
+      if (state->neteci_mode == true) {
+	ecasound_launch_neteci(state);
       }
     }
 
@@ -165,12 +165,10 @@ int main(int argc, char *argv[])
     }
   }
 
-  if (state->daemon_mode == true) {
-    /* wait until daemon thread has exited */
-    if (state->interactive_mode == true) {
-      state->exit_request = 1;
-    }
-    pthread_join(*state->daemon_thread, NULL);
+  if (state->neteci_mode == true) {
+    /* wait until the NetECI thread has exited */
+    state->exit_request = 1;
+    pthread_join(*state->neteci_thread, NULL);
   }
 
   /* note: if we exist due to a signal, we never reach 
@@ -223,7 +221,7 @@ void ecasound_exit_cleanup(void)
     if (state->launchcmds != 0) { delete state->launchcmds; state->launchcmds = 0; }
     if (state->eciserver != 0) { delete state->eciserver; state->eciserver = 0; }
     if (state->console != 0) { delete state->console; state->console = 0; }
-    if (state->daemon_thread != 0) { delete state->daemon_thread; state->daemon_thread = 0; }
+    if (state->neteci_thread != 0) { delete state->neteci_thread; state->neteci_thread = 0; }
     if (state->lock != 0) { delete state->lock; state->lock = 0; }
     if (state->signalset != 0) { delete state->signalset; state->signalset = 0; }
   }
@@ -254,29 +252,29 @@ void ecasound_create_eca_objects(struct ecasound_state* state,
 }
 
 /**
- * Launches a background daemon that allows NetECI 
+ * Launches a background thread that allows NetECI 
  * clients to connect to the current ecasound
  * session.
  */
-void ecasound_launch_daemon(struct ecasound_state* state)
+void ecasound_launch_neteci(struct ecasound_state* state)
 {
   DBC_REQUIRE(state != 0);
   // DBC_REQUIRE(state->console != 0);
 
   // state->console->print("ecasound: starting the NetECI server.");
 
-  state->daemon_thread = new pthread_t;
+  state->neteci_thread = new pthread_t;
   state->lock = new pthread_mutex_t;
   pthread_mutex_init(state->lock, NULL);
   state->eciserver = new ECA_NETECI_SERVER(state);
 
-  int res = pthread_create(state->daemon_thread, 
+  int res = pthread_create(state->neteci_thread, 
 			   NULL,
 			   ECA_NETECI_SERVER::launch_server_thread, 
 			   reinterpret_cast<void*>(state->eciserver));
   if (res != 0) {
-    cerr << "ecasound: Warning! Unable to create daemon thread." << endl;
-    delete state->daemon_thread;  state->daemon_thread = 0;
+    cerr << "ecasound: Warning! Unable to create a thread for control over socket connection (NetECI)." << endl;
+    delete state->neteci_thread;  state->neteci_thread = 0;
     delete state->lock;  state->lock = 0;
     delete state->eciserver; state->eciserver = 0;
   }
@@ -299,6 +297,31 @@ static int ecasound_pass_at_launch_commands(struct ecasound_state* state)
   return 0;
 }
 
+static void ecasound_check_for_quit(struct ecasound_state* state, const string& cmd)
+{
+  if (cmd == "quit" || cmd == "q") {
+    state->console->print("---\necasound: Exiting...");
+    state->exit_request = 1;
+    ECA_LOGGER::instance().flush();
+  }
+}
+
+static void ecasound_lock_ctrl_if_needed(struct ecasound_state* state)
+{
+  if (state->neteci_mode == true) {
+    int res = pthread_mutex_lock(state->lock);
+    DBC_CHECK(res == 0);
+  }
+}
+
+static void ecasound_unlock_ctrl_if_needed(struct ecasound_state* state)
+{
+  if (state->neteci_mode == true) {
+    int res = pthread_mutex_unlock(state->lock);
+    DBC_CHECK(res == 0);
+  }
+}
+
 /**
  * The main processing loop.
  */
@@ -310,62 +333,86 @@ void ecasound_main_loop(struct ecasound_state* state)
   ECA_CONTROL* ctrl = state->control;
 
   if (state->interactive_mode == true) {
+
+    /* case 1: interactive mode */
+
     while(state->exit_request == 0) {
       state->console->read_command("ecasound ('h' for help)> ");
       const string& cmd = state->console->last_command();
       if (cmd.size() > 0 && state->exit_request == 0) {
 
-	if (state->daemon_mode == true) {
-	  int res = pthread_mutex_lock(state->lock);
-	  DBC_CHECK(res == 0);
-	}
-
+	ecasound_lock_ctrl_if_needed(state);
 	ctrl->command(cmd);
 	ctrl->print_last_value();
+	ecasound_unlock_ctrl_if_needed(state);
 
-	if (state->daemon_mode == true) {
-	  int res = pthread_mutex_unlock(state->lock);
-	  DBC_CHECK(res == 0);
-	}
-
-	if (cmd == "quit" || cmd == "q") {
-	  state->console->print("---\necasound: Exiting...");
-	  state->exit_request = 1;
-	  ECA_LOGGER::instance().flush();
-	}
+	ecasound_check_for_quit(state, cmd);
       }
     }
   }
   else {
-    /* non-interactive mode */
 
-    if (state->daemon_mode == true) {
-      int res = pthread_mutex_lock(state->lock);
-      DBC_CHECK(res == 0);
-    }
+    /* case 2: non-interactive mode */
 
+    /* FIXME: to be split into separate functions */
+
+    ecasound_lock_ctrl_if_needed(state);
     if (ctrl->is_selected() == true && 
 	ctrl->is_valid() == true) {
       ctrl->connect_chainsetup();
     }
+    ecasound_unlock_ctrl_if_needed(state);
 
-    if (ctrl->is_connected() == true) {
-      if (!state->exit_request) {
-	int res = ctrl->run(!state->keep_running_mode);
-	if (res < 0) {
-	  state->retval = ECASOUND_RETVAL_RUNTIME_ERROR;
-	  cerr << "ecasound: Warning! Errors detected during processing." << endl;
+    if (state->neteci_mode != true) {
+
+      /* case: 2.1: non-interactive, NetECI not in use */
+
+      if (ctrl->is_connected() == true) {
+	if (!state->exit_request) {
+	  int res = ctrl->run(!state->keep_running_mode);
+	  if (res < 0) {
+	    state->retval = ECASOUND_RETVAL_RUNTIME_ERROR;
+	    cerr << "ecasound: Warning! Errors detected during processing." << endl;
+	  }
 	}
       }
+      else {
+	ctrl->print_last_value();
+	state->retval = ECASOUND_RETVAL_START_ERROR;
+      }
     }
     else {
-      ctrl->print_last_value();
-      state->retval = ECASOUND_RETVAL_START_ERROR;
-    }
 
-    if (state->daemon_mode == true) {
-      int res = pthread_mutex_unlock(state->lock);
-      DBC_CHECK(res == 0);
+      /* case: 2.2: non-interactive, NetECI active */
+
+      int res = -1;
+
+      ecasound_lock_ctrl_if_needed(state);
+      if (ctrl->is_connected() == true) {
+	res = ctrl->start();
+      }
+      ecasound_unlock_ctrl_if_needed(state);
+
+      /* note: if keep_running_mode is enabled, we do not 
+       *       exit even if there are errors during startup */
+      if (state->keep_running_mode != true &&
+	  res < 0) {
+	state->retval = ECASOUND_RETVAL_START_ERROR;
+	state->exit_request = 1;
+      }
+
+      while(state->exit_request == 0) {
+	
+	if (state->keep_running_mode != true &&
+	    ctrl->is_finished() == true)
+	  break;
+	
+	/* note: sleep for one second and let the NetECI thread
+	 *       access the ECA_CONTROL object for a while */
+	kvu_sleep(1, 0);
+      }
+
+      ecasound_check_for_quit(state, "quit");
     }
   }
   // cerr << endl << "ecasound: mainloop exiting..." << endl;
@@ -407,8 +454,10 @@ void ecasound_parse_command_line(struct ecasound_state* state,
 	state->cerr_output_only_mode = true;
       }
       
-      else if (cline.current() == "--daemon") {
-	state->daemon_mode = true;
+      else if (cline.current() == "--server" ||
+	       cline.current() == "--daemon") {
+	/* note: --daemon* deprecated as of 2.6.0 */
+	state->neteci_mode = true;
       }
 
       else if (cline.current().find("-E") != string::npos) {
@@ -420,18 +469,21 @@ void ecasound_parse_command_line(struct ecasound_state* state,
 	}
       }
 
-      else if (cline.current().find("--daemon-port") != string::npos) {
+      else if (cline.current().find("--server-tcp-port") != string::npos ||
+	       cline.current().find("--daemon-port") != string::npos) {
 	std::vector<std::string> argpair = 
 	  kvu_string_to_vector(cline.current(), '=');
 	if (argpair.size() > 1) {
-	  /* --daemon-port=XXXX */
-	  state->daemon_port = atoi(argpair[1].c_str());
+	  /* --server-tcp-port=XXXX */
+	  /* note: --daemon* deprecated as of 2.6.0 */
+	  state->neteci_tcp_port = atoi(argpair[1].c_str());
 	}
       }
 
-
-      else if (cline.current() == "--nodaemon") {
-	state->daemon_mode = false;
+      else if (cline.current() == "--no-server" ||
+	       cline.current() == "--nodaemon") {
+	/* note: --daemon deprecated as of 2.6.0 */
+	state->neteci_mode = false;
       }
 
       else if (cline.current() == "-h" ||
@@ -470,7 +522,7 @@ void ecasound_print_usage(void)
 void ecasound_print_version_banner(void)
 {
   cout << "ecasound v" << ecasound_library_version << endl;
-  cout << "Copyright (C) 1997-2008 Kai Vehmanen and others." << endl;
+  cout << "Copyright (C) 1997-2009 Kai Vehmanen and others." << endl;
   cout << "Ecasound comes with ABSOLUTELY NO WARRANTY." << endl;
   cout << "You may redistribute copies of ecasound under the terms of the GNU" << endl;
   cout << "General Public License. For more information about these matters, see" << endl; 
