@@ -18,7 +18,7 @@ class ECA_SESSION;
  */
 
 #define ECASOUND_BANNER_ASTERISK_BAR "********************************************************************************\n"
-#define ECASOUND_COPYRIGHT           " (C) 1997-2008 Kai Vehmanen and others    "
+#define ECASOUND_COPYRIGHT           " (C) 1997-2009 Kai Vehmanen and others    "
 
 #define ECASOUND_RETVAL_SUCCESS         0    /**< Succesful run */
 #define ECASOUND_RETVAL_INIT_FAILURE    1    /**< Unable to initialize */
@@ -39,13 +39,13 @@ struct ecasound_state {
   ECA_NETECI_SERVER* eciserver;
   ECA_SESSION* session;
   std::vector<std::string>* launchcmds;
-  pthread_t* daemon_thread;
+  pthread_t* neteci_thread;
   pthread_mutex_t* lock;
   sig_atomic_t exit_request;
   sigset_t* signalset;
   int retval;
-  int daemon_port;
-  bool daemon_mode;
+  int neteci_tcp_port;
+  bool neteci_mode;
   bool keep_running_mode;
   bool cerr_output_only_mode;
   bool interactive_mode;
