@@ -30,6 +30,7 @@
 #include <algorithm> /* std::count() */
 #include <iostream>
 #include <string>
+#include <utility>
 
 #include <sys/time.h> /* gettimeofday() */
 #include <errno.h> /* ETIMEDOUT */
@@ -83,11 +84,11 @@ static int eca_jack_process_callback(jack_nframes_t nframes, void *arg);
 static int eca_jack_sync_callback(jack_transport_state_t state, jack_position_t *pos, void *arg);
 static void eca_jack_sync_start_seek_to(jack_transport_state_t state, jack_position_t *pos, void *arg);
 static void eca_jack_sync_start_live_seek_to(jack_transport_state_t state, jack_position_t *pos, void *arg);
+static void eca_jack_process_timebase_slave(jack_nframes_t nframes, void *arg);
 #endif
 
 static void eca_jack_process_engine_iteration(jack_nframes_t nframes, void *arg);
 static void eca_jack_process_mute(jack_nframes_t nframes, void* arg);
-static void eca_jack_process_timebase_slave(jack_nframes_t nframes, void *arg);
 #ifdef PROFILE_CALLBACK_EXECUTION
 static void eca_jack_process_profile_pre(void);
 static void eca_jack_process_profile_post(void);
@@ -498,6 +499,7 @@ static void eca_jack_process_mute(jack_nframes_t nframes, void* arg)
   }
 }
 
+#if ECA_JACK_TRANSPORT_API >= 3
 /**
  * Helper routine. Only called by eca_jack_process_callback() function.
  *
@@ -505,7 +507,6 @@ static void eca_jack_process_mute(jack_nframes_t nframes, void* arg)
  */
 static void eca_jack_process_timebase_slave(jack_nframes_t nframes, void *arg)
 {
-#if ECA_JACK_TRANSPORT_API >= 3
   AUDIO_IO_JACK_MANAGER* current = static_cast<AUDIO_IO_JACK_MANAGER*>(arg);
   jack_transport_state_t jackstate;
   jack_position_t jackpos;
@@ -575,8 +576,8 @@ static void eca_jack_process_timebase_slave(jack_nframes_t nframes, void *arg)
   if (need_mute == true) {
     eca_jack_process_mute(nframes, current);
   }
-#endif
 }
+#endif
 
 #ifdef PROFILE_CALLBACK_EXECUTION
 static void eca_jack_process_profile_pre(void)
@@ -895,6 +896,7 @@ void AUDIO_IO_JACK_MANAGER::set_parameter(int param, std::string value)
 
     case 2: 
       {
+#if ECA_JACK_TRANSPORT_API >= 3
 	if (value == "notransport" || 
 	    value == "streaming") {
 	  mode_rep = AUDIO_IO_JACK_MANAGER::Transport_none;
@@ -918,6 +920,12 @@ void AUDIO_IO_JACK_MANAGER::set_parameter(int param, std::string value)
 	  ECA_LOG_MSG(ECA_LOGGER::user_objects, 
 		      "'recv' mode selected.");
 	}
+#else
+	mode_rep = AUDIO_IO_JACK_MANAGER::Transport_none;
+	if (value != "notransport")
+	  ECA_LOG_MSG(ECA_LOGGER::info, 
+		      "WARNING: JACK transport support disabled at build time, using 'notransport'.");
+#endif /* ECA_JACK_TRANSPORT_API */
 	break;
       }
     }
@@ -1417,8 +1425,13 @@ void AUDIO_IO_JACK_MANAGER::register_jack_ports(int client_id, int ports, const
     portdata->total_latency = 0;
     portdata->cb_buffer = new jack_default_audio_sample_t [cb_allocated_frames_rep];
 
+    std::map<string, int>::iterator it = port_numbers_rep.find(portprefix);
+    if (it == port_numbers_rep.end()) {
+      it = port_numbers_rep.insert(std::make_pair(portprefix, 0)).first;
+    }
+    string tport = portprefix + "_" + kvu_numtostr(++it->second);
+
     if (node->aobj->io_mode() == AUDIO_IO::io_read) {
-      string tport = portprefix + "_" + kvu_numtostr(inports_rep.size() + 1);
       portdata->jackport = jack_port_register(client_repp, 
 					      tport.c_str(), 
 					      JACK_DEFAULT_AUDIO_TYPE, 
@@ -1427,7 +1440,6 @@ void AUDIO_IO_JACK_MANAGER::register_jack_ports(int client_id, int ports, const
       inports_rep.push_back(portdata);
     }
     else {
-      string tport = portprefix + "_" + kvu_numtostr(outports_rep.size() + 1);
       portdata->jackport = jack_port_register(client_repp, 
 					      tport.c_str(), 
 					      JACK_DEFAULT_AUDIO_TYPE, 
@@ -1710,6 +1722,8 @@ void AUDIO_IO_JACK_MANAGER::close_server_connection(void)
 
   open_rep = false;
 
+  port_numbers_rep.clear();
+
   ECA_LOG_MSG(ECA_LOGGER::user_objects, 
 		"Succesfully closed JACK server connection.");
 
